gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r6410 - in GNUnet: libltdl m4 src/applications/chat src/app


From: gnunet
Subject: [GNUnet-SVN] r6410 - in GNUnet: libltdl m4 src/applications/chat src/applications/fs/ecrs src/applications/fs/gap src/transports src/util/network
Date: Thu, 21 Feb 2008 23:22:44 -0700 (MST)

Author: grothoff
Date: 2008-02-21 23:22:44 -0700 (Thu, 21 Feb 2008)
New Revision: 6410

Modified:
   GNUnet/libltdl/ltmain.sh
   GNUnet/m4/Makefile.in
   GNUnet/src/applications/chat/chat.c
   GNUnet/src/applications/chat/clientapi.c
   GNUnet/src/applications/fs/ecrs/search.c
   GNUnet/src/applications/fs/gap/fs.c
   GNUnet/src/applications/fs/gap/querymanager.c
   GNUnet/src/applications/fs/gap/querymanager.h
   GNUnet/src/transports/http.c
   GNUnet/src/util/network/select.c
Log:
formatting

Modified: GNUnet/libltdl/ltmain.sh
===================================================================
--- GNUnet/m4/Makefile.in       2008-02-22 06:22:15 UTC (rev 6409)
+++ GNUnet/m4/Makefile.in       2008-02-22 06:22:44 UTC (rev 6410)
@@ -72,6 +72,7 @@
 DEPDIR = @DEPDIR@
 DLLDIR = @DLLDIR@
 DLLTOOL = @DLLTOOL@
+DSYMUTIL = @DSYMUTIL@
 ECHO = @ECHO@
 ECHO_C = @ECHO_C@
 ECHO_N = @ECHO_N@
@@ -120,6 +121,7 @@
 MSGMERGE = @MSGMERGE@
 MYSQL_CPPFLAGS = @MYSQL_CPPFLAGS@
 MYSQL_LDFLAGS = @MYSQL_LDFLAGS@
+NMEDIT = @NMEDIT@
 OBJDUMP = @OBJDUMP@
 OBJEXT = @OBJEXT@
 PACKAGE = @PACKAGE@

Modified: GNUnet/src/applications/chat/chat.c
===================================================================
--- GNUnet/src/applications/chat/chat.c 2008-02-22 06:22:15 UTC (rev 6409)
+++ GNUnet/src/applications/chat/chat.c 2008-02-22 06:22:44 UTC (rev 6410)
@@ -52,7 +52,7 @@
 
 };
 
-static struct GNUNET_CS_chat_client * client_list_head;
+static struct GNUNET_CS_chat_client *client_list_head;
 
 static int
 csHandleChatMSG (struct GNUNET_ClientHandle *client,
@@ -77,7 +77,7 @@
   cmsg = (CS_chat_MESSAGE *) message;
   if (ntohs (cmsg->header.size) < sizeof (CS_chat_MESSAGE))
     {
-      GNUNET_GE_BREAK(NULL, 0);
+      GNUNET_GE_BREAK (NULL, 0);
       return GNUNET_SYSERR;     /* invalid message */
     }
 
@@ -165,7 +165,7 @@
 
   if (ntohs (cmsg->header.size) < sizeof (CS_chat_JOIN_MESSAGE))
     {
-      GNUNET_GE_BREAK(NULL, 0);
+      GNUNET_GE_BREAK (NULL, 0);
       return GNUNET_SYSERR;     /* invalid message */
     }
 
@@ -197,21 +197,20 @@
   /*TODO: create client context on the server, very simple as of now */
 #if EXTRA_CHECKS
   tempClient = client_list;
-  while ( (tempClient->client != client) &&
-         (tempClient != NULL) )
+  while ((tempClient->client != client) && (tempClient != NULL))
     tempClient = tempClient->next;
   if (tempClient != NULL)
     {
-      GNUNET_GE_BREAK(NULL, 0);
+      GNUNET_GE_BREAK (NULL, 0);
       GNUNET_free (nick);
       GNUNET_free (client_key);
       GNUNET_free (room_name);
       GNUNET_mutex_unlock (chatMutex);
-      return GNUNET_SYSERR;      
+      return GNUNET_SYSERR;
     }
 #endif
   tempClient = GNUNET_malloc (sizeof (struct GNUNET_CS_chat_client));
-  memset(tempClient, 0, sizeof (struct GNUNET_CS_chat_client));
+  memset (tempClient, 0, sizeof (struct GNUNET_CS_chat_client));
   tempClient->next = client_list_head;
   if (client_list_head != NULL)
     client_list_head->prev = tempClient;
@@ -275,8 +274,8 @@
 {
   int tempCount;
 
-  struct GNUNET_CS_chat_client * pos;
-  struct GNUNET_CS_chat_client * prev;
+  struct GNUNET_CS_chat_client *pos;
+  struct GNUNET_CS_chat_client *prev;
 
   /*client_key = GNUNET_malloc (sizeof (GNUNET_RSA_PublicKey));
      memcpy (client_key, &cmsg->nick[nick_len], pubkey_len); */
@@ -291,20 +290,20 @@
   /*TODO: delete client context on the server */
   pos = client_list_head;
   prev = NULL;
-  while ( (pos != NULL) && (pos->client != client) )
-       {
+  while ((pos != NULL) && (pos->client != client))
+    {
       prev = pos;
       pos = pos->next;
     }
   if (pos != NULL)
-       {
+    {
       if (prev == NULL)
-       client_list_head = pos->next;
+        client_list_head = pos->next;
       else
-       prev->next = pos->next;
+        prev->next = pos->next;
       if (pos->next != NULL)
-       pos->next->prev = pos->prev;
-      GNUNET_free(pos);
+        pos->next->prev = pos->prev;
+      GNUNET_free (pos);
     }
   /*Count the number of current clients, will be removed */
 #if NATE
@@ -332,7 +331,7 @@
   GNUNET_GE_ASSERT (ectx,
                     sizeof (P2P_chat_MESSAGE) == sizeof (CS_chat_MESSAGE));
   chatMutex = GNUNET_mutex_create (GNUNET_NO);
-  
+
   coreAPI = capi;
   GNUNET_GE_LOG (ectx, GNUNET_GE_DEBUG | GNUNET_GE_REQUEST | GNUNET_GE_USER,
                  _("`%s' registering handlers %d and %d\n"),

Modified: GNUnet/src/applications/chat/clientapi.c
===================================================================
--- GNUnet/src/applications/chat/clientapi.c    2008-02-22 06:22:15 UTC (rev 
6409)
+++ GNUnet/src/applications/chat/clientapi.c    2008-02-22 06:22:44 UTC (rev 
6410)
@@ -59,7 +59,7 @@
   char *memberInfo;
 
   GNUNET_CHAT_MessageCallback callback;
-  
+
   int shutdown_flag;
 
   void *callback_cls;
@@ -92,36 +92,37 @@
   while (room->shutdown_flag != GNUNET_YES)
     {
       if (disconnected)
-       {
-         if (GNUNET_client_connection_ensure_connected (room->sock) != 
GNUNET_OK)
-           {
-             disconnected = GNUNET_YES;
-             /* send join! */
-           }
-         else
-           {
-             GNUNET_thread_sleep(5 * GNUNET_CRON_SECONDS);
-             continue;
+        {
+          if (GNUNET_client_connection_ensure_connected (room->sock) !=
+              GNUNET_OK)
+            {
+              disconnected = GNUNET_YES;
+              /* send join! */
+            }
+          else
+            {
+              GNUNET_thread_sleep (5 * GNUNET_CRON_SECONDS);
+              continue;
+            }
         }
-    }
 
       reply = NULL;
 
       if (GNUNET_OK != GNUNET_client_connection_read (room->sock, &reply))
-       {
-         disconnected = GNUNET_YES;
-         continue;
-       }
+        {
+          disconnected = GNUNET_YES;
+          continue;
+        }
 
       if ((reply->size <
            ntohs (sizeof (GNUNET_MessageHeader) + sizeof (CS_chat_MESSAGE)))
           || (reply->type != ntohs (GNUNET_CS_PROTO_CHAT_MSG)))
-       {
-         GNUNET_GE_BREAK(NULL, 0);
-         GNUNET_client_connection_close_temporarily(room->sock);
-         disconnected = GNUNET_YES;
-         continue;
-       }
+        {
+          GNUNET_GE_BREAK (NULL, 0);
+          GNUNET_client_connection_close_temporarily (room->sock);
+          disconnected = GNUNET_YES;
+          continue;
+        }
 
       size = ntohs (reply->size);
 
@@ -239,7 +240,7 @@
     {
       /* ALREADY LOGGED */
       fprintf (stderr, _("Error writing to socket.\n"));
-      GNUNET_free(join_msg);
+      GNUNET_free (join_msg);
       return NULL;
     }
 
@@ -278,11 +279,11 @@
 void
 GNUNET_CHAT_leave_room (struct GNUNET_CHAT_Room *chat_room)
 {
-  void * unused;
+  void *unused;
   chat_room->shutdown_flag = GNUNET_YES;
   GNUNET_client_connection_close_forever (chat_room->sock);
-  GNUNET_thread_stop_sleep(chat_room->listen_thread);
-  GNUNET_thread_join(chat_room->listen_thread, &unused);
+  GNUNET_thread_stop_sleep (chat_room->listen_thread);
+  GNUNET_thread_join (chat_room->listen_thread, &unused);
   GNUNET_free (chat_room->nickname);
   GNUNET_free (chat_room->memberInfo);
   GNUNET_client_connection_destroy (chat_room->sock);

Modified: GNUnet/src/applications/fs/ecrs/search.c
===================================================================
--- GNUnet/src/applications/fs/ecrs/search.c    2008-02-22 06:22:15 UTC (rev 
6409)
+++ GNUnet/src/applications/fs/ecrs/search.c    2008-02-22 06:22:44 UTC (rev 
6410)
@@ -331,7 +331,7 @@
                                                 (const DBlock *) &value[1],
                                                 GNUNET_YES, &query))
     {
-      GNUNET_GE_BREAK(NULL, 0);
+      GNUNET_GE_BREAK (NULL, 0);
       return GNUNET_SYSERR;
     }
   if (!((0 == memcmp (&query,
@@ -345,7 +345,7 @@
                                                      (GNUNET_HashCode *) &
                                                      ps[1]))))
     {
-      return GNUNET_OK;           /* not a match */
+      return GNUNET_OK;         /* not a match */
     }
 
   switch (type)
@@ -360,10 +360,10 @@
         int j;
 
         if (size < sizeof (KBlock))
-         {
-           GNUNET_GE_BREAK(NULL, 0);
-           return GNUNET_SYSERR;
-         }
+          {
+            GNUNET_GE_BREAK (NULL, 0);
+            return GNUNET_SYSERR;
+          }
         kb = GNUNET_malloc (size);
         memcpy (kb, &value[1], size);
 #if DEBUG_SEARCH

Modified: GNUnet/src/applications/fs/gap/fs.c
===================================================================
--- GNUnet/src/applications/fs/gap/fs.c 2008-02-22 06:22:15 UTC (rev 6409)
+++ GNUnet/src/applications/fs/gap/fs.c 2008-02-22 06:22:44 UTC (rev 6410)
@@ -445,11 +445,12 @@
   type = ntohl (dblock->type);
   GNUNET_free_non_null (enc);
   ret = coreAPI->cs_send_to_client (sock, &msg->header,
-                                   type != GNUNET_ECRS_BLOCKTYPE_DATA ? 
GNUNET_NO : GNUNET_YES);
+                                    type !=
+                                    GNUNET_ECRS_BLOCKTYPE_DATA ? GNUNET_NO :
+                                    GNUNET_YES);
   GNUNET_free (msg);
-  if ( (type == GNUNET_ECRS_BLOCKTYPE_DATA) || 
-       (ret != GNUNET_OK) )
-    return GNUNET_SYSERR;       /* unique response or client can take no more*/
+  if ((type == GNUNET_ECRS_BLOCKTYPE_DATA) || (ret != GNUNET_OK))
+    return GNUNET_SYSERR;       /* unique response or client can take no more 
*/
   rl = GNUNET_malloc (sizeof (struct ResponseList));
   GNUNET_hash (dblock, size, &rl->hash);
   rl->next = cls->seen;
@@ -517,8 +518,7 @@
   GNUNET_FS_QUERYMANAGER_start_query (&rs->query[0], keyCount, anonymityLevel,
                                       type, sock,
                                       have_target ? &rs->target : NULL,
-                                      fpp.seen,
-                                     fpp.have_more);
+                                      fpp.seen, fpp.have_more);
 CLEANUP:
   while (fpp.seen != NULL)
     {

Modified: GNUnet/src/applications/fs/gap/querymanager.c
===================================================================
--- GNUnet/src/applications/fs/gap/querymanager.c       2008-02-22 06:22:15 UTC 
(rev 6409)
+++ GNUnet/src/applications/fs/gap/querymanager.c       2008-02-22 06:22:44 UTC 
(rev 6410)
@@ -70,7 +70,7 @@
  */
 static struct ClientDataList *clients;
 
-static GNUNET_CoreAPIForPlugins * coreAPI;
+static GNUNET_CoreAPIForPlugins *coreAPI;
 
 static GNUNET_Stats_ServiceAPI *stats;
 
@@ -133,7 +133,7 @@
                                     struct GNUNET_ClientHandle *client,
                                     const GNUNET_PeerIdentity * target,
                                     const struct ResponseList *seen,
-                                   int have_more)
+                                    int have_more)
 {
   struct ClientDataList *cl;
   struct RequestList *request;
@@ -279,13 +279,13 @@
   msg->expirationTime = GNUNET_htonll (expirationTime);
   memcpy (&msg[1], data, size);
   coreAPI->cs_send_to_client (client,
-                             &msg->header,
-                             (rl->type != GNUNET_ECRS_BLOCKTYPE_DATA)
-                             ? GNUNET_NO : GNUNET_YES);
+                              &msg->header,
+                              (rl->type != GNUNET_ECRS_BLOCKTYPE_DATA)
+                              ? GNUNET_NO : GNUNET_YES);
   if (stats != NULL)
     stats->change (stat_gap_client_response_sent, 1);
   GNUNET_free (msg);
-  
+
   /* update *value */
   *value += 1 + rl->value;
   GNUNET_FS_PLAN_success (sender, client, 0, rl);
@@ -438,7 +438,7 @@
 
 struct HMClosure
 {
-  struct RequestList * request;  
+  struct RequestList *request;
   unsigned int processed;
   int have_more;
 };
@@ -463,9 +463,9 @@
   size = ntohl (value->size) - sizeof (GNUNET_DatastoreValue);
   dblock = (const DBlock *) &value[1];
   if (GNUNET_OK == GNUNET_FS_SHARED_test_valid_new_response (cls->request,
-                                                            key,
-                                                            size,
-                                                            dblock, &hc))
+                                                             key,
+                                                             size,
+                                                             dblock, &hc))
     {
       msg = GNUNET_malloc (sizeof (CS_fs_reply_content_MESSAGE) + size);
       msg->header.type = htons (GNUNET_CS_PROTO_GAP_RESULT);
@@ -474,13 +474,11 @@
       msg->expirationTime = value->expirationTime;
       memcpy (&msg[1], dblock, size);
       ret = coreAPI->cs_send_to_client (cls->request->response_client,
-                                       &msg->header,
-                                       GNUNET_YES);
+                                        &msg->header, GNUNET_YES);
       GNUNET_free (msg);
       if (ret != GNUNET_OK)
-       return GNUNET_SYSERR;       /* client can take no more */       
-      GNUNET_FS_SHARED_mark_response_seen(cls->request,
-                                         &hc);
+        return GNUNET_SYSERR;   /* client can take no more */
+      GNUNET_FS_SHARED_mark_response_seen (cls->request, &hc);
     }
   cls->processed++;
   if (cls->processed > MAX_ASYNC_PROCESSED)
@@ -512,40 +510,41 @@
       request = client->requests;
       while (request != NULL)
         {
-         if (request->have_more > 0)
-           {
-             request->have_more--;
-             hmc.request = request;
-             hmc.processed = 0;
-             hmc.have_more = GNUNET_NO;
-             datastore->get (&request->queries[0], request->type, 
&have_more_processor, &hmc);
-             if (hmc.have_more)
-               request->have_more += HAVE_MORE_INCREMENT;
-           }
-         else
-           {
-             if ((NULL == request->plan_entries) &&
-                 ((client->client != NULL) ||
-                  (request->expiration > now)) &&
-                 (request->last_ttl_used * GNUNET_CRON_SECONDS +
-                  request->last_request_time < now))
-               {
-                 if ((GNUNET_OK ==
-                      GNUNET_FS_PLAN_request (client->client, 0, request))
-                     && (stats != NULL))
-                   stats->change (stat_gap_client_query_injected, 1);
-               }
-             
-             if ((request->anonymityLevel == 0) &&
-                 (request->last_dht_get + request->dht_back_off < now))
-               {
-                 if (request->dht_back_off * 2 > request->dht_back_off)
-                   request->dht_back_off *= 2;
-                 request->last_dht_get = now;
-                 GNUNET_FS_DHT_execute_query (request->type,
-                                              &request->queries[0]);
-               }
-           }
+          if (request->have_more > 0)
+            {
+              request->have_more--;
+              hmc.request = request;
+              hmc.processed = 0;
+              hmc.have_more = GNUNET_NO;
+              datastore->get (&request->queries[0], request->type,
+                              &have_more_processor, &hmc);
+              if (hmc.have_more)
+                request->have_more += HAVE_MORE_INCREMENT;
+            }
+          else
+            {
+              if ((NULL == request->plan_entries) &&
+                  ((client->client != NULL) ||
+                   (request->expiration > now)) &&
+                  (request->last_ttl_used * GNUNET_CRON_SECONDS +
+                   request->last_request_time < now))
+                {
+                  if ((GNUNET_OK ==
+                       GNUNET_FS_PLAN_request (client->client, 0, request))
+                      && (stats != NULL))
+                    stats->change (stat_gap_client_query_injected, 1);
+                }
+
+              if ((request->anonymityLevel == 0) &&
+                  (request->last_dht_get + request->dht_back_off < now))
+                {
+                  if (request->dht_back_off * 2 > request->dht_back_off)
+                    request->dht_back_off *= 2;
+                  request->last_dht_get = now;
+                  GNUNET_FS_DHT_execute_query (request->type,
+                                               &request->queries[0]);
+                }
+            }
           request = request->next;
         }
       client = client->next;

Modified: GNUnet/src/applications/fs/gap/querymanager.h
===================================================================
--- GNUnet/src/applications/fs/gap/querymanager.h       2008-02-22 06:22:15 UTC 
(rev 6409)
+++ GNUnet/src/applications/fs/gap/querymanager.h       2008-02-22 06:22:44 UTC 
(rev 6410)
@@ -52,7 +52,7 @@
                                     struct GNUNET_ClientHandle *client,
                                     const GNUNET_PeerIdentity * target,
                                     const struct ResponseList *seen,
-                                   int have_more);
+                                    int have_more);
 
 /**
  * Handle the given response (by forwarding it to

Modified: GNUnet/src/transports/http.c
===================================================================
--- GNUnet/src/transports/http.c        2008-02-22 06:22:15 UTC (rev 6409)
+++ GNUnet/src/transports/http.c        2008-02-22 06:22:44 UTC (rev 6410)
@@ -558,20 +558,19 @@
   else
     {
       httpsession->destroyed = GNUNET_YES;
-      GNUNET_GE_BREAK(NULL,
-                     httpsession->cs.server.puts == NULL);
+      GNUNET_GE_BREAK (NULL, httpsession->cs.server.puts == NULL);
 #if DO_GET
       gpos = httpsession->cs.server.gets;
       while (gpos != NULL)
         {
-         GNUNET_mutex_lock (gpos->lock);
-         GNUNET_array_grow (gpos->wbuff, gpos->wsize, 0);
+          GNUNET_mutex_lock (gpos->lock);
+          GNUNET_array_grow (gpos->wbuff, gpos->wsize, 0);
           r = gpos->get;
           gpos->get = NULL;
           /* contentReaderFreeCallback WILL
              destroy gpos->lock/gpos */
           gnext = gpos->next;
-         GNUNET_mutex_unlock (gpos->lock);
+          GNUNET_mutex_unlock (gpos->lock);
           MHD_destroy_response (r);
           gpos = gnext;
         }
@@ -805,9 +804,8 @@
   ENTER ();
 #if DEBUG_HTTP
   GNUNET_GE_LOG (coreAPI->ectx,
-                GNUNET_GE_DEBUG | GNUNET_GE_REQUEST | GNUNET_GE_USER,
-                "HTTP/MHD receives `%s' request.\n",
-                method);
+                 GNUNET_GE_DEBUG | GNUNET_GE_REQUEST | GNUNET_GE_USER,
+                 "HTTP/MHD receives `%s' request.\n", method);
 #endif
   /* convert URL to sender peer id */
   if ((strlen (url) < 2)
@@ -1740,9 +1738,9 @@
           if ((s->cs.client.last_get_activity + HTTP_TIMEOUT < now) &&
               ((s->users > 0) || (s->cs.client.puts != NULL)) &&
               ((s->cs.client.last_get_initiated + HTTP_GET_REFRESH > now) ||
-               (s->cs.client.get == NULL) ) &&
-             ((s->cs.client.get == NULL) ||
-               (s->cs.client.last_get_activity + HTTP_GET_REFRESH / 2 < now)))
+               (s->cs.client.get == NULL)) &&
+              ((s->cs.client.get == NULL) ||
+               (s->cs.client.last_get_activity + HTTP_GET_REFRESH / 2 < now)))
             create_curl_get (s);
 #endif
         }

Modified: GNUnet/src/util/network/select.c
===================================================================
--- GNUnet/src/util/network/select.c    2008-02-22 06:22:15 UTC (rev 6409)
+++ GNUnet/src/util/network/select.c    2008-02-22 06:22:44 UTC (rev 6410)
@@ -378,7 +378,8 @@
       GNUNET_GE_LOG (sh->ectx,
                      GNUNET_GE_DEBUG | GNUNET_GE_DEVELOPER | GNUNET_GE_BULK,
                      "Sending %d bytes from session %p of select %s return 
%d.\n",
-                     session->wapos - session->wspos, session, 
sh->description, ret);
+                     session->wapos - session->wspos, session,
+                     sh->description, ret);
 #endif
       if (ret == GNUNET_SYSERR)
         {





reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- GNUnet/libltdl/ltmain.sh    2008-02-22 06:22:15 UTC (rev 6409)
+++ GNUnet/libltdl/ltmain.sh    2008-02-22 06:22:44 UTC (rev 6410)
@@ -2,7 +2,7 @@
 # NOTE: Changing this file will not affect anything until you rerun configure.
 #
 # Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2003, 2004, 2005, 2006,
 # 2007  Free Software Foundation, Inc.
 # Originally by Gordon Matzigkeit <address@hidden>, 1996
 #
 # This program is free software; you can redistribute it and/or modify
@@ -43,8 +43,8 @@
 
 PROGRAM=ltmain.sh
 PACKAGE=libtool
-VERSION="1.5.24 Debian 1.5.24-2"
-TIMESTAMP=" (1.1220.2.456 2007/06/24 02:25:32)"
+VERSION="1.5.26 Debian 1.5.26-1"
+TIMESTAMP=" (1.1220.2.493 2008/02/01 16:58:18)"
 
 # Be Bourne compatible (taken from Autoconf:_AS_BOURNE_COMPATIBLE).
 if test -n "${ZSH_VERSION+set}" && (emulate sh) >/dev/null 2>&1; then
@@ -113,15 +113,21 @@
 # These must not be set unconditionally because not all systems understand
 # e.g. LANG=C (notably SCO).
 # We save the old values to restore during execute mode.
-for lt_var in LANG LC_ALL LC_CTYPE LC_COLLATE LC_MESSAGES
+lt_env=
+for lt_var in LANG LANGUAGE LC_ALL LC_CTYPE LC_COLLATE LC_MESSAGES
 do
   eval "if test \"\${$lt_var+set}\" = set; then
          save_$lt_var=\$$lt_var
+         lt_env=\"$lt_var=\$$lt_var \$lt_env\"
          $lt_var=C
          export $lt_var
        fi"
 done
 
+if test -n "$lt_env"; then
+  lt_env="env $lt_env"
+fi
+
 # Make sure IFS has a sensible default
 lt_nl='
 '
@@ -485,7 +491,7 @@
     echo "\
 $PROGRAM (GNU $PACKAGE) $VERSION$TIMESTAMP
 
-Copyright (C) 2007  Free Software Foundation, Inc.
+Copyright (C) 2008  Free Software Foundation, Inc.
 This is free software; see the source for copying conditions.  There is NO
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
     exit $?
@@ -788,6 +794,7 @@
     *.for) xform=for ;;
     *.java) xform=java ;;
     *.obj) xform=obj ;;
+    *.sx) xform=sx ;;
     esac
 
     libobj=`$echo "X$libobj" | $Xsed -e "s/\.$xform$/.lo/"`
@@ -956,7 +963,7 @@
       $run $rm "$lobj" "$output_obj"
 
       $show "$command"
-      if $run eval "$command"; then :
+      if $run eval $lt_env "$command"; then :
       else
        test -n "$output_obj" && $run $rm $removelist
        exit $EXIT_FAILURE
@@ -1028,7 +1035,7 @@
       command="$command$suppress_output"
       $run $rm "$obj" "$output_obj"
       $show "$command"
-      if $run eval "$command"; then :
+      if $run eval $lt_env "$command"; then :
       else
        $run $rm $removelist
        exit $EXIT_FAILURE
@@ -1161,6 +1168,7 @@
     thread_safe=no
     vinfo=
     vinfo_number=no
+    single_module="${wl}-single_module"
 
     func_infer_tag $base_compile
 
@@ -1646,6 +1654,11 @@
        continue
        ;;
 
+      -multi_module)
+       single_module="${wl}-multi_module"
+       continue
+       ;;
+
       -module)
        module=yes
        continue
@@ -2152,7 +2165,12 @@
            continue
          fi
          name=`$echo "X$deplib" | $Xsed -e 's/^-l//'`
-         for searchdir in $newlib_search_path $lib_search_path 
$sys_lib_search_path $shlib_search_path; do
+         if test "$linkmode" = lib; then
+           searchdirs="$newlib_search_path $lib_search_path 
$compiler_lib_search_dirs $sys_lib_search_path $shlib_search_path"
+         else
+           searchdirs="$newlib_search_path $lib_search_path 
$sys_lib_search_path $shlib_search_path"
+         fi
+         for searchdir in $searchdirs; do
            for search_ext in .la $std_shrext .so .a; do
              # Search the libtool library
              lib="$searchdir/lib${name}${search_ext}"
@@ -2948,12 +2966,18 @@
                  # we do not want to link against static libs,
                  # but need to link against shared
                  eval deplibrary_names=`${SED} -n -e 
's/^library_names=\(.*\)$/\1/p' $deplib`
+                 eval deplibdir=`${SED} -n -e 's/^libdir=\(.*\)$/\1/p' $deplib`
                  if test -n "$deplibrary_names" ; then
                    for tmp in $deplibrary_names ; do
                      depdepl=$tmp
                    done
-                   if test -f "$path/$depdepl" ; then
+                   if test -f "$deplibdir/$depdepl" ; then
+                     depdepl="$deplibdir/$depdepl"
+                   elif test -f "$path/$depdepl" ; then
                      depdepl="$path/$depdepl"
+                   else
+                     # Can't find it, oh well...
+                     depdepl=
                    fi
                    # do not add paths which are already there
                    case " $newlib_search_path " in
@@ -3101,9 +3125,10 @@
 
     case $linkmode in
     oldlib)
-      if test -n "$deplibs"; then
-       $echo "$modename: warning: \`-l' and \`-L' are ignored for archives" 
1>&2
-      fi
+      case " $deplibs" in
+      *\ -l* | *\ -L*)
+       $echo "$modename: warning: \`-l' and \`-L' are ignored for archives" 
1>&2 ;;
+      esac
 
       if test -n "$dlfiles$dlprefiles" || test "$dlself" != no; then
        $echo "$modename: warning: \`-dlopen' is ignored for archives" 1>&2
@@ -4245,9 +4270,10 @@
       ;;
 
     obj)
-      if test -n "$deplibs"; then
-       $echo "$modename: warning: \`-l' and \`-L' are ignored for objects" 1>&2
-      fi
+      case " $deplibs" in
+      *\ -l* | *\ -L*)
+       $echo "$modename: warning: \`-l' and \`-L' are ignored for objects" 
1>&2 ;;
+      esac
 
       if test -n "$dlfiles$dlprefiles" || test "$dlself" != no; then
        $echo "$modename: warning: \`-dlopen' is ignored for objects" 1>&2
@@ -6486,7 +6512,7 @@
       fi
 
       # Restore saved environment variables
-      for lt_var in LANG LC_ALL LC_CTYPE LC_COLLATE LC_MESSAGES
+      for lt_var in LANG LANGUAGE LC_ALL LC_CTYPE LC_COLLATE LC_MESSAGES
       do
        eval "if test \"\${save_$lt_var+set}\" = set; then
                $lt_var=\$save_$lt_var; export $lt_var
@@ -2,7 +2,7 @@
 #
 # Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2003, 2004, 2005, 2006,
-# 2007  Free Software Foundation, Inc.
+# 2007, 2008  Free Software Foundation, Inc.
 # Originally by Gordon Matzigkeit <address@hidden>, 1996
 #

Modified: GNUnet/m4/Makefile.in
===================================================================